@@ -6,14 +6,12 @@ use utf8;
 use Template::Reverse::Util;
 use constant::Atom qw(WILDCARD BOF EOF);
 use Algorithm::Diff qw(sdiff);
-use Scalar::Util qw(blessed);
-use Data::Dumper;
 use List::Util qw(max min);
 require Exporter;
 our @ISA = 'Exporter';
 our @EXPORT = qw(WILDCARD BOF EOF);
 
-our $VERSION = '0.201'; # VERSION
+our $VERSION = '0.202'; # VERSION
 
 
 has 'sidelen' => (
@@ -84,7 +82,7 @@ Template::Reverse - A template generator getting different parts between pair of
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
