@@ -3,9 +3,8 @@ package Template::Reverse::Converter::Regexp;
 # ABSTRACT: Convert parts to Regular Expression simply
 
 use Moo;
-use Scalar::Util qw(blessed);
 use utf8;
-our $VERSION = '0.201'; # VERSION
+our $VERSION = '0.202'; # VERSION
 
 sub Convert{
     my $self = shift;
@@ -50,15 +49,15 @@ Template::Reverse::Converter::Regexp - Convert parts to Regular Expression simpl
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
     package Template::Reverse::Converter::Regexp;
     my $tt2 = Template::Reverse::Converter::Regexp->new;
-    my $res = $tt2->Convert([[['pretext'],['posttext']]]);
-	"Some text" =~ /$res/;
-	print $1;
+    my $res = $tt2->Convert([{pre=>['The'],post=>['stuff']}]);
+    "The cool stuff" =~ /$res/;
+    print $1; # "cool"
 
 =head1 AUTHOR
 
